summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepasswordedaccount.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/libkopete/kopetepasswordedaccount.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/libkopete/kopetepasswordedaccount.h')
-rw-r--r--kopete/libkopete/kopetepasswordedaccount.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kopetepasswordedaccount.h b/kopete/libkopete/kopetepasswordedaccount.h
index 210adbd4..4be22016 100644
--- a/kopete/libkopete/kopetepasswordedaccount.h
+++ b/kopete/libkopete/kopetepasswordedaccount.h
@@ -74,15 +74,15 @@ public:
/**
* @brief Go online for this service.
*
* @param initialStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/
- void connect( const OnlineStatus& initialStatus );
+ void connect( const OnlineStatus& initialtqStatus );
/**
* \brief Get the initial status
*/
- OnlineStatus initialStatus();
+ OnlineStatus initialtqStatus();
/**
* @brief Remove the account from the server.
@@ -74,15 +74,15 @@ public:
* @brief Go online for this service.
*
- * @param initialStatus is the status to connect with. If it is an invalid status for this
+ * @param initialtqStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/